summaryrefslogtreecommitdiff
path: root/test/WhiteBoxTests.cpp
diff options
context:
space:
mode:
authorTor Lillqvist <tml@collabora.com>2018-09-12 19:05:01 +0300
committerTor Lillqvist <tml@collabora.com>2018-09-12 19:27:23 +0300
commit87b85ff8f0761a3461cb2615b0f70670865cdaef (patch)
tree0fe4ef22aee21ccb908325256e510f05bcf85b0d /test/WhiteBoxTests.cpp
parentb59d160a085796c567e114a62483438ed761c31a (diff)
Be consistent in how we name "interface" abstract classes
We already use a suffix "Interface" for SocketHandlerInterface, so rename IDocumentManager to DocumentManagerInterface. Naming "interface" classes with an "I" prefix is C# and COM style. Sure, that is a convention as good as any other, but let's try to be consistent within this rather small code-base. Change-Id: I9c356df327debd780f23ed2b2e6d6e630328861e
Diffstat (limited to 'test/WhiteBoxTests.cpp')
-rw-r--r--test/WhiteBoxTests.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/WhiteBoxTests.cpp b/test/WhiteBoxTests.cpp
index 580df11e3..a85b09fbd 100644
--- a/test/WhiteBoxTests.cpp
+++ b/test/WhiteBoxTests.cpp
@@ -323,8 +323,8 @@ void WhiteBoxTests::testRegexListMatcher_Init()
CPPUNIT_ASSERT(matcher.match("192.168.."));
}
-/// A stub IDocumentManager implementation for unit test purposes.
-class DummyDocument : public IDocumentManager
+/// A stub DocumentManagerInterface implementation for unit test purposes.
+class DummyDocument : public DocumentManagerInterface
{
std::shared_ptr<TileQueue> _tileQueue;
std::mutex _mutex;